@@ -6,7 +6,7 @@ from easytradesdk.Const import KlinePeriod
 
 class BackTestContext(AbsContext):
 
-    def __init__(self):
+    def __init__(self, backTestCode):
         self.__executePeriod = None
         self.__executingTimeMills = None
         self.__marketApi = None
@@ -20,6 +20,7 @@ class BackTestContext(AbsContext):
         self.backTestEndTime = None
         self.buySlippage = None
         self.sellSlippage = None
+        self.backTestCode = backTestCode
         self.backTestOrders = []
 
     def getPosition(self, tc, symbol):
